import Qs from 'qs'
import axios from 'axios'
import C from './c.js'
import utils from './utils.js'
import apis from './api.js'

const net = {
  req: (params, vm) => {
    if (!params) {
      return new Promise((resolve, reject) => {
        reject(new Error('请设置请求参数'))
      })
    }
    if (!params.url) {
      return new Promise((resolve, reject) => {
        reject(new Error('请设置请求url'))
      })
    }
    return new Promise((resolve, reject) => {
      params.data = utils.deepClone(params.data) || {}
      let userToken = utils.storage.fetch('userToken')
      if (userToken) {
        params.data.user_token = userToken
      }
      if (!params.method) {
        params.method = 'post'
      }
      let config = {
        url: params.url,
        method: params.method,
        headers: {
          'X-Requested-With': 'XMLHttpRequest',
          'Content-Type': 'application/x-www-form-urlencoded'
        },
        responseType: params.responseType || 'json',
        timeout: 30000,
        paramsSerializer: function (params) {
          return Qs.stringify(params, {
            arrayFormat: 'brackets'
          })
        },
        transformRequest: [function (data, headers) {
          return Qs.stringify(data, {
            arrayFormat: 'brackets'
          })
        }]
      }
      if (params.method.toLowerCase() === 'get') {
        Object.assign(config, {
          params: Object.assign(params.data, {
            timestamp: Date.parse(new Date()) / 1000
          })
        })
      } else {
        Object.assign(config, {
          params: {
            timestamp: Date.parse(new Date()) / 1000
          },
          data: params.data
        })
      }
      axios(config).then((response) => {
        C.DEBUG && console.log(`${params.url}---response--->`, response)
        let {data, status} = response
        if (parseInt(status) === 200) {
          let {code} = data
          code = parseInt(code)
          if (parseInt(code) === 0) {
            resolve(data)
          } else if (C.CODE_NOT_LOGIN === code) {
            utils.storage.clear()
            if (vm) {
              let {fullPath} = vm.$route
              vm.$router.push({
                path: `/login?targetUrl=${encodeURIComponent(fullPath)}`,
                replace: true
              })
            }
          } else {
            reject(data)
          }
        } else {
          reject(response)
        }
      }).catch((e) => {
        C.DEBUG && console.log(`${params.url}---catch--->`, e)
        reject(e)
      })
      C.DEBUG && console.log(`${params.url}---params--->`, config)
    })
  },
  login: (account, password, success, fail) => {
    let params = {}
    params.url = apis.api_admin_login
    params.data = {
      account: account,
      password: password
    }
    net.req(params).then(
      data => {
        if (data) {
          let userInfo = data.data
          if (userInfo) {
            if (userInfo.admin_token) {
              utils.storage.save('userToken', userInfo.admin_token)
            }
            userInfo = encodeURIComponent(JSON.stringify(userInfo))
            utils.storage.save('userInfo', userInfo)
          }
        }
        success && success(data)
      },
      e => {
        fail && fail(e)
      }
    )
  }
}

export default net
