const utils = {
  storage: {
    save: (key, value) => {
      let result = null
      if (window) {
        result = window.localStorage.setItem(key, JSON.stringify(value))
      }
      return result
    },
    fetch: (key) => {
      let result = null
      if (window && key) {
        result = JSON.parse(window.localStorage.getItem(key))
      }
      return result
    },
    remove: (key) => {
      if (window) {
        window.localStorage.removeItem(key)
      }
    },
    clear: () => {
      if (window) {
        window.localStorage.clear()
      }
    }
  },
  queryString: (name) => {
    var result = location.search.match(new RegExp('[?&]' + name + '=([^&]+)', 'i'))
    if (result == null || result.length < 1) {
      return ''
    }
    return decodeURIComponent(result[1])
  },
  deepClone: (obj) => { /* 深度克隆对象 */
    if (obj === null || typeof obj !== 'object') {
      return obj
    }
    let clone
    if (obj instanceof Date) {
      clone = new Date()
      clone.setTime(obj.getTime())
      return clone
    }
    if (obj instanceof Array) {
      clone = []
      let i
      let n = obj.length
      for (i = 0; i < n; i++) {
        clone[i] = utils.deepClone(obj[i])
      }
      return clone
    }
    if (obj instanceof Object) {
      clone = {}
      for (let key in obj) {
        if (obj.hasOwnProperty(key)) {
          clone[key] = utils.deepClone(obj[key])
        }
      }
      return clone
    }
    throw new Error(`Unable to clone obj! Its type isn't supported.`)
  },
  checkIsLogin: () => {
    let userToken = utils.storage.fetch('userToken')
    if (userToken) {
      return true
    } else {
      return false
    }
  }
}

export default utils
